bayespy.inference.vmp.nodes.constant.Constant.plates_multiplier
===============================================================

.. currentmodule:: bayespy.inference.vmp.nodes.constant

.. autoattribute:: Constant.plates_multiplier